@@ -1,9 +1,9 @@
-#ifndef __MOBIUS_IO_BYTEARRAY_IO_H__
-#define __MOBIUS_IO_BYTEARRAY_IO_H__
+#ifndef MOBIUS_IO_BYTEARRAY_IO_H
+#define MOBIUS_IO_BYTEARRAY_IO_H
 
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 // Mobius Forensic Toolkit
-// Copyright (C) 2008,2009,2010,2011,2012,2013,2014,2015,2016,2017,2018 Eduardo Aguiar
+// Copyright (C) 2008,2009,2010,2011,2012,2013,2014,2015,2016,2017,2018,2019,2020,2021,2022,2023,2024,2025 Eduardo Aguiar
 //
 // This program is free software; you can redistribute it and/or modify it
 // under the terms of the GNU General Public License as published by the
@@ -19,17 +19,13 @@
 // along with this program. If not, see <http://www.gnu.org/licenses/>.
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 #include <mobius/io/reader.h>
-//#include <mobius/io/writer.h>
+#include <mobius/io/writer.h>
 
-namespace mobius
-{
-namespace io
+namespace mobius::io
 {
+reader new_bytearray_reader (const bytearray&);
+writer new_bytearray_writer (bytearray&);
 
-const reader new_bytearray_reader (const bytearray&);
-//const writer new_bytearray_writer (bytearray&);
-
-} // namespace io
-} // namespace mobius
+} // namespace mobius::io
 
 #endif
