@@ -1,6 +1,6 @@
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 // Mobius Forensic Toolkit
-// Copyright (C) 2008,2009,2010,2011,2012,2013,2014,2015,2016,2017,2018,2019,2020,2021,2022,2023 Eduardo Aguiar
+// Copyright (C) 2008,2009,2010,2011,2012,2013,2014,2015,2016,2017,2018,2019,2020,2021,2022,2023,2024,2025 Eduardo Aguiar
 //
 // This program is free software; you can redistribute it and/or modify it
 // under the terms of the GNU General Public License as published by the
@@ -20,11 +20,7 @@
 #include <mobius/exception.inc>
 #include <stdexcept>
 
-namespace mobius
-{
-namespace os
-{
-namespace win
+namespace mobius::os::win
 {
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 //! \brief PBKDF2 key derivation function (with HMAC) - MS version
@@ -32,7 +28,7 @@ namespace win
 //! \param salt salt
 //! \param count iterations count
 //! \param dklen derived key length in bytes
-//! \param hash_id hash algorithm (e.g. "md2", "md5", "sha1", "sha2_256")
+//! \param hash_id hash algorithm (e.g. "md2", "md5", "sha1", "sha2-256")
 // This function implements MS version, which is not compatible with RFC 2898
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 mobius::bytearray
@@ -45,12 +41,12 @@ pbkdf2_hmac_ms (
 {
   // Validate input parameters
   if (dklen == 0)
-    throw std::out_of_range (MOBIUS_EXCEPTION_MSG ("Derived key length must be > 0"));
+    throw std::out_of_range (MOBIUS_EXCEPTION_MSG ("derived key length must be > 0"));
 
   // Calculate derived key
   std::uint32_t i = 1;
   mobius::bytearray dk;
-  mobius::crypt::hmac hmac (password, hash_id);
+  mobius::crypt::hmac hmac (hash_id, password);
 
   while (dk.size () < dklen)
     {
@@ -81,6 +77,4 @@ pbkdf2_hmac_ms (
   return dk.slice (0, dklen - 1);
 }
 
-} // namespace win
-} // namespace os
-} // namespace mobius
+} // namespace mobius::os::win
