@@ -5,7 +5,7 @@ import sys
 
 
 def get_hash(reader):
-    h = mobius.crypt.hash('sha2_512')
+    h = mobius.crypt.hash('sha2-512')
     data = reader.read(65536)
     while data:
         h.update(data)
@@ -50,7 +50,7 @@ app.start()
 
 for url in sys.argv[1:]:
     vfs = mobius.vfs.vfs()
-    vfs.add_datasource(mobius.vfs.new_datasource_by_url(url))
+    vfs.add_disk(mobius.vfs.new_disk_by_url(url))
 
     if vfs.is_available():
         print_kff(vfs)
